@@ -1,19 +1,30 @@
-#! /usr/bin/envb python
+#! /usr/bin/env python
 
 # http://stackoverflow.com/questions/12003805/threadsafe-and-fault-tolerant-file-writes
 
 import logtool, os, tempfile
 
 class AtomicTempFile (object): # pylint: disable=R0903
+  """A temporary file object which will be atomically renamed to the
+  specified path on exit.  This allows transactional behaviours with
+  file writes.
+
+  Args:
+
+    final_path (string): path to the final file
+    **kwargs (dict): Will be passed to :class:`tempfile.NamedTemporaryFile`.
+      As the tempoaray file will be created in the same directory as the final
+      file, the current process must have write access to that directory.
+  """
 
   @logtool.log_call
   def __init__(self, final_path, **kwargs):
     tmpfile_dir = kwargs.pop ('dir', None)
     if tmpfile_dir is None:
-      tmpfile_dir = os.path.dirname (final_path)
-    self.tmpfile = tempfile.NamedTemporaryFile (dir = tmpfile_dir, **kwargs)
+      tmpfile_dir = os.path.dirname (str (final_path)) # str cast for broken pathlib
+    self.tmpfile = tempfile.NamedTemporaryFile (dir = tmpfile_dir,
+                                                delete = False, **kwargs)
     self.final_path = final_path
-    # FIXME: Initialise the tempfile with the prior content?
 
   @logtool.log_call
   def __getattr__ (self, attr):
